import React from 'react';
import Dialog from '@material-ui/core/Dialog';
import DialogContent from '@material-ui/core/DialogContent';
import DialogTitle from '@material-ui/core/DialogTitle';
import {Button, DialogActions, DialogContentText} from "@material-ui/core";
import ButtonWithSpinner from "./ButtonWithSpinner";


export interface DeleteConfirmationDialogContent {
  id: string,
  type: string,
  title: string,
}

interface DeleteConfirmationDialogProps {
  content: DeleteConfirmationDialogContent,
  open: boolean,
  loading?: boolean,

  handleConfirmButtonClick(): void,

  handleClose(): void,
}

export default function DeleteConfirmationDialog(props: DeleteConfirmationDialogProps) {
  return (
    <Dialog
      open={props.open}
      onClose={props.handleClose}
      aria-labelledby="alert-dialog-title"
      aria-describedby="alert-dialog-description"
    >
      <DialogTitle id="alert-dialog-title">{props.content.type} löschen?</DialogTitle>
      <DialogContent>
        <DialogContentText id="alert-dialog-description">
          Möchten Sie die {props.content.type}
          "{props.content.title}"
          wirklich löschen?
        </DialogContentText>
      </DialogContent>
      <DialogActions>
        <Button onClick={props.handleClose} color="primary">
          Abbrechen
        </Button>
        <ButtonWithSpinner onClick={props.handleConfirmButtonClick} autoFocus loading={props.loading}>
          Löschen
        </ButtonWithSpinner>
      </DialogActions>
    </Dialog>
  );
}

